#ifndef COLUMBUSDIALOGWAYPOINTS_H
#define COLUMBUSDIALOGWAYPOINTS_H

#include "widgets/ColumbusDialog.h"

class ColumbusDialogWaypointsPrivate;

class ColumbusDialogWaypoints : public ColumbusDialog
{
    Q_OBJECT

public:
    explicit ColumbusDialogWaypoints(QWidget *parent = 0);
            ~ColumbusDialogWaypoints();

    void setController(ColumbusController *controller);

protected slots:
    void setupUi();
    void updateUi();

private:
    ColumbusDialogWaypointsPrivate *d;
};

#endif // COLUMBUSDIALOGWAYPOINTS_H
